@@ -6,7 +6,7 @@
 #SBATCH --time=04:00:00                  # Time limit hrs:min:sec
 #SBATCH --output="{{ qspool::job_log_path }}/a=log+{{ qspool::qspool_job_name }}+slurm_job_id=%j+ext=.txt"
 
-__version__ = "0.2.5"
+__version__ = "0.2.6"
 __author__ = "Matthew Andres moreno"
 
 import argparse
@@ -62,7 +62,8 @@ qspool_job_title = instantiation_or_none(
     "{{ qspool::qspool_job_title }}",
 )
 this_script_template = instantiation_or_none(
-    r"""{{ qspool::this_script_template }}""",
+    r""" {{ qspool::this_script_template }} """,
+    apply=lambda x: json.loads(x, strict=False),
 )
 
 
@@ -311,7 +312,7 @@ if __name__ == "__main__":
             .replace("{{ qspool::qspool_job_title }}", qspool_job_title, 1)
             .replace(
                 "{{ qspool::this_script_template }}",
-                json.dumps(this_script_template)[1:-1],
+                json.dumps(this_script_template),
                 1,
             )
         )
